Index: src/mips/code-stubs-mips.cc |
diff --git a/src/mips/code-stubs-mips.cc b/src/mips/code-stubs-mips.cc |
index 3d0577eb1e540761ecbbfb1831bb1d8ccbbbb4aa..6ce6e36fead978033b31810f7e53668a44f24d0f 100644 |
--- a/src/mips/code-stubs-mips.cc |
+++ b/src/mips/code-stubs-mips.cc |
@@ -3860,7 +3860,7 @@ void InstanceofStub::Generate(MacroAssembler* masm) { |
__ Subu(inline_site, ra, scratch); |
// Get the map location in scratch and patch it. |
__ GetRelocatedValue(inline_site, scratch, v1); // v1 used as scratch. |
- __ sw(map, FieldMemOperand(scratch, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(map, FieldMemOperand(scratch, PropertyCell::kValueOffset)); |
} |
// Register mapping: a3 is object map and t0 is function prototype. |
@@ -5043,7 +5043,7 @@ static void GenerateRecordCallTargetNoArray(MacroAssembler* masm) { |
masm->isolate()->heap()->the_hole_value()); |
// Load the cache state into a3. |
- __ lw(a3, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ lw(a3, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
// A monomorphic cache hit or an already megamorphic state: invoke the |
// function without changing the state. |
@@ -5059,13 +5059,13 @@ static void GenerateRecordCallTargetNoArray(MacroAssembler* masm) { |
// An uninitialized cache is patched with the function. |
// Store a1 in the delay slot. This may or may not get overwritten depending |
// on the result of the comparison. |
- __ sw(a1, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(a1, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
// No need for a write barrier here - cells are rescanned. |
// MegamorphicSentinel is an immortal immovable object (undefined) so no |
// write-barrier is needed. |
__ LoadRoot(at, Heap::kUndefinedValueRootIndex); |
- __ sw(at, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(at, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
__ bind(&done); |
} |
@@ -5086,7 +5086,7 @@ static void GenerateRecordCallTarget(MacroAssembler* masm) { |
masm->isolate()->heap()->the_hole_value()); |
// Load the cache state into a3. |
- __ lw(a3, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ lw(a3, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
// A monomorphic cache hit or an already megamorphic state: invoke the |
// function without changing the state. |
@@ -5117,7 +5117,7 @@ static void GenerateRecordCallTarget(MacroAssembler* masm) { |
// write-barrier is needed. |
__ bind(&megamorphic); |
__ LoadRoot(at, Heap::kUndefinedValueRootIndex); |
- __ sw(at, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(at, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
__ jmp(&done); |
// An uninitialized cache is patched with the function or sentinel to |
@@ -5134,11 +5134,11 @@ static void GenerateRecordCallTarget(MacroAssembler* masm) { |
TypeFeedbackCells::MonomorphicArraySentinel(masm->isolate(), |
GetInitialFastElementsKind()); |
__ li(a3, Operand(initial_kind_sentinel)); |
- __ sw(a3, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(a3, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
__ Branch(&done); |
__ bind(¬_array_function); |
- __ sw(a1, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(a1, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
// No need for a write barrier here - cells are rescanned. |
__ bind(&done); |
@@ -5214,7 +5214,7 @@ void CallFunctionStub::Generate(MacroAssembler* masm) { |
ASSERT_EQ(*TypeFeedbackCells::MegamorphicSentinel(masm->isolate()), |
masm->isolate()->heap()->undefined_value()); |
__ LoadRoot(at, Heap::kUndefinedValueRootIndex); |
- __ sw(at, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ sw(at, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
} |
// Check for function proxy. |
__ Branch(&non_function, ne, a3, Operand(JS_FUNCTION_PROXY_TYPE)); |
@@ -7776,7 +7776,7 @@ void ArrayConstructorStub::Generate(MacroAssembler* masm) { |
__ Assert(eq, "Unexpected initial map for Array function", |
t0, Operand(MAP_TYPE)); |
// We should either have undefined in ebx or a valid jsglobalpropertycell |
Label okay_here; |
Handle<Map> global_property_cell_map( |
masm->isolate()->heap()->global_property_cell_map()); |
@@ -7791,7 +7791,7 @@ void ArrayConstructorStub::Generate(MacroAssembler* masm) { |
Label no_info, switch_ready; |
// Get the elements kind and case on that. |
__ Branch(&no_info, eq, a2, Operand(undefined_sentinel)); |
- __ lw(a3, FieldMemOperand(a2, JSGlobalPropertyCell::kValueOffset)); |
+ __ lw(a3, FieldMemOperand(a2, PropertyCell::kValueOffset)); |
__ JumpIfNotSmi(a3, &no_info); |
__ SmiUntag(a3); |
__ jmp(&switch_ready); |
@@ -7776,7 +7776,7 @@ void ArrayConstructorStub::Generate(MacroAssembler* masm) { |
__ Assert(eq, "Unexpected initial map for Array function", |
t0, Operand(MAP_TYPE)); |
- // We should either have undefined in ebx or a valid jsglobalpropertycell |
+ // We should either have undefined in ebx or a valid PropertyCell |
Label okay_here; |
Handle<Map> global_property_cell_map( |